%define sys_assert on

Name:      crash-worker
Summary:    Crash-manager
Version:    0.3.0
Release:    1
Group:      Framework/system
License:    Apache-2.0 and PD
Source0:    %{name}-%{version}.tar.gz
Source1001:    crash-worker.manifest
BuildRequires:  pkgconfig(dlog)
BuildRequires:  pkgconfig(libtzplatform-config)
BuildRequires:  pkgconfig(capi-system-info)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  cmake
%if "%{?sys_assert}" == "on"
BuildRequires:  pkgconfig(libunwind)
%endif
BuildRequires:  libelf-devel libelf
BuildRequires:  libebl-devel libebl
BuildRequires:  libdw-devel libdw

Requires(post): coreutils
Requires(post): tar
Requires(post): gzip
Requires: libunwind
# If you need support for core dump files (see building below),
# you should add this dependency
# Requires: libebl

%description
crash-manager

%prep
%setup -q

#Path to store logs and coredump files
%define crash_root_path %{TZ_SYS_CRASH_ROOT}
%define crash_path      %{TZ_SYS_CRASH}
%define crash_temp      %{crash_root_path}/temp

#Path for log_dump module
%define crash_all_log   %{TZ_SYS_ALLLOGS}
%define crash_dump_gen  %{TZ_SYS_DUMPGEN}

%define upgrade_script_path %{TZ_SYS_RO_SHARE}/upgrade/scripts

#Engineer mode
%define eng_mode_path   %{TZ_SYS_ETC}

%build
cp %{SOURCE1001} .

export CFLAGS+=" -Werror"

%ifarch %{arm} aarch64
	%define ARCH arm
%else
	%define ARCH x86
%endif

%ifarch %{arm} %ix86
	%define ARCH_BIT 32
%else
	%define ARCH_BIT 64
%endif

%if 0%{?tizen_build_devel_mode}
	%define eng_mode on
%else
	%define eng_mode off
%endif

%cmake . \
	   -DCMAKE_INSTALL_PREFIX=%{_prefix} \
	   -DTMP_FILES_DIR=%{_sysconfdir}/tmpfiles.d \
	   -DARCH=%{ARCH} \
	   -DARCH_BIT=%{ARCH_BIT} \
	   -DTZ_SYS_BIN=%{TZ_SYS_BIN} \
	   -DCRASH_ROOT_PATH=%{crash_root_path} \
	   -DCRASH_PATH=%{crash_path} \
	   -DCRASH_TEMP=%{crash_temp} \
	   -DCRASH_PIPE_PATH=%{_libexecdir}/crash-pipe \
	   -DCRASH_STACK_PATH=%{_libexecdir}/crash-stack \
	   -DSYS_ASSERT=%{sys_assert} \
	   -DUPGRADE_SCRIPT_PATH=%{upgrade_script_path}
# to add support for core dump files add backslash at the end of above line
# and uncomment below line:
#	   -DWITH_CORE_DUMP=ON

make %{?jobs:-j%jobs}

%install
rm -rf %{buildroot}
%make_install
mkdir -p %{buildroot}%{crash_root_path}
mkdir -p %{buildroot}%{crash_path}
mkdir -p %{buildroot}%{crash_temp}

# log_dump dir
mkdir -p %{buildroot}%{crash_all_log}
mkdir -p %{buildroot}%{crash_dump_gen}
cp dump_scripts/* %{buildroot}%{crash_dump_gen}

%if "%{eng_mode}" == "on"
install -m 644 src/crash-manager/debugmode %{buildroot}%{eng_mode_path}/.debugmode
%endif

%if "%{?sys_assert}" == "on"

%post
if [ ! -d /.build ]; then
	orig="%{_libdir}/libsys-assert.so"
	pattern=$(echo $orig | sed -e 's|/|\\/|g')
	ret=$(sed -n "/${pattern}/p"  %{_sysconfdir}/ld.so.preload)
	if [ -z "$ret" ]; then
		echo "%{_libdir}/libsys-assert.so" >> %{_sysconfdir}/ld.so.preload
	fi
	chmod 644 %{_sysconfdir}/ld.so.preload
fi

/usr/bin/chsmack -a "System::Shared" -t %{crash_path}
/usr/bin/chsmack -a "System::Shared" -t %{crash_temp}

/sbin/ldconfig

%postun
orig="%{_libdir}/libsys-assert.so"
pattern=$(echo $orig | sed -e 's|/|\\/|g')
sed -i "/${pattern}/D" %{_sysconfdir}/ld.so.preload
/sbin/ldconfig

%endif

%files
%license LICENSE
%manifest crash-worker.manifest
%defattr(-,system,system,-)
%dir %{crash_root_path}
%dir %{crash_path}
%dir %{crash_temp}
%dir %{crash_all_log}
%{crash_dump_gen}/*
%attr(0755,system,system) %{_bindir}/dump_systemstate
%attr(0755,system,system) %{_bindir}/crash-manager.sh
%attr(0755,system,system) %{_bindir}/log_dump
%{_prefix}/lib/sysctl.d/99-crash-manager.conf
%{_datadir}/dbus-1/system-services/org.tizen.system.crash.service

%if "%{?sys_assert}" == "on"
%{_libdir}/libsys-assert.so
%{_sysconfdir}/tmpfiles.d/sys-assert.conf
%endif

%{_libexecdir}/crash-pipe
%{_libexecdir}/crash-stack

%if "%{eng_mode}" == "on"
%{eng_mode_path}/.debugmode
%endif

#upgrade script
%attr(-,root,root) %{upgrade_script_path}/crash-manager-upgrade.sh
